======================
:code:`Trakt['oauth']`
======================

.. automodule:: trakt.interfaces.oauth

  .. autoclass:: OAuthInterface
    :members: authorize_url, pin_url, token, token_exchange, token_refresh
    :undoc-members:
